@@ -12,16 +12,25 @@ __license__ = "Apache 2.0"
 import logging
 from fastapi import APIRouter
 
-logger = logging.getLogger("app_chem")
+from rcsb.utils.chem.ChemCompSearchWrapper import ChemCompSearchWrapper
+
+logger = logging.getLogger(__name__)
 
 router = APIRouter()
 
 
 @router.get("/status", tags=["status"])
 def serverStatus():
-    return {"msg": "Sevice is up!"}
+    ccsw = ChemCompSearchWrapper()
+    ccsw.status()
+    return {"msg": "Service is up!"}
 
 
 @router.get("/", tags=["status"])
 def rootServerStatus():
-    return {"msg": "Sevice is up!"}
+    return {"msg": "Service is up!"}
+
+
+@router.get("/healthcheck", tags=["status"])
+def rootHealthCheck():
+    return "UP"
